var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
import { R as safeJSONStringify } from "./kit-ddc495fb.js";
function getStorage(key, defaultValue = null) {
  if (typeof window === "undefined")
    throw new Error();
  const value = localStorage.getItem(key);
  if (!value)
    return defaultValue;
  try {
    return JSON.parse(value);
  } catch (e) {
    return value;
  }
}
const setStorage = (key, value) => {
  window.localStorage.setItem(key, "" + value);
};
class Node {
  constructor(key, value) {
    __publicField(this, "key");
    __publicField(this, "value");
    __publicField(this, "prev");
    __publicField(this, "next");
    this.key = key;
    this.value = value;
    this.prev = null;
    this.next = null;
  }
}
class LRUCache {
  constructor(capacity) {
    __publicField(this, "capacity");
    __publicField(this, "usedCapacity");
    __publicField(this, "head");
    __publicField(this, "tail");
    __publicField(this, "store");
    this.capacity = capacity || 20;
    this.usedCapacity = 0;
    this.store = {};
    this.head = new Node("fakeHeadNode", "fakeHeadNode");
    this.tail = new Node("fakeTailNode", "fakeTailNode");
    this.head.next = this.tail;
    this.tail.prev = this.head;
  }
  removeNode(node) {
    node.prev.next = node.next;
    node.next.prev = node.prev;
  }
  addToHead(node) {
    node.prev = this.head;
    node.next = this.head.next;
    this.head.next.prev = node;
    this.head.next = node;
  }
  moveToHead(node) {
    this.removeNode(node);
    this.addToHead(node);
  }
  removeTail() {
    const node = this.tail.prev;
    this.removeNode(node);
    return node;
  }
  delete(key) {
    if (key in this.store) {
      const node = this.store[key];
      this.removeNode(node);
    }
  }
  get(key) {
    if (key in this.store) {
      const node = this.store[key];
      this.moveToHead(node);
      return node.value;
    }
    return -1;
  }
  put(key, value) {
    if (key in this.store) {
      const node = this.store[key];
      node.value = value;
      this.moveToHead(node);
    } else {
      const node = new Node(key, value);
      this.addToHead(node);
      this.store[key] = node;
      this.usedCapacity += 1;
      if (this.usedCapacity > this.capacity) {
        const tailNode = this.removeTail();
        delete this.store[tailNode.key];
        this.usedCapacity -= 1;
      }
    }
  }
  keys() {
    const res = [];
    let node = this.head;
    while (node) {
      res.push(node.key);
      node = node.next;
    }
    return res.slice(1, -1);
  }
  values() {
    const res = [];
    let node = this.head;
    while (node) {
      res.push(node.value);
      node = node.next;
    }
    return res.slice(1, -1);
  }
  toJSON() {
    return this.store;
  }
}
const createKeysLocalStorageLRUCache = (storageKey, capacity) => {
  const lruCache = new LRUCache(capacity);
  const manager = {
    syncFromStorage() {
      const data = getStorage(storageKey) || [];
      data.slice().reverse().forEach((key) => {
        lruCache.put(key, key);
      });
    },
    syncToStorage() {
      setStorage(storageKey, safeJSONStringify(lruCache.keys()));
    },
    remove(key) {
      lruCache.delete(key);
      this.syncToStorage();
    },
    put(key) {
      lruCache.put(key, key);
      this.syncToStorage();
    },
    get(key) {
      return key ? lruCache.get(key) : lruCache.keys();
    }
  };
  manager.syncFromStorage();
  return manager;
};
export {
  createKeysLocalStorageLRUCache as c
};
